@@ -30,12 +30,13 @@
 
 #include <gdk/gdkscreen.h>
 #include <gdk/gdkx.h>
-#include <glade/glade.h>
 #include <libgnomeui/gnome-help.h>
 
 #define GROUPS_SUBMENU_PATH "/popups/popup/groups"
 #define PLUGINS_CAPPLET_EXECUTABLE "gkbd-indicator-plugins-capplet"
 
+#define GTK_RESPONSE_PRINT 2
+
 /* we never build applet without XKB, so far: TODO */
 #define HAVE_XKB  1
 
@@ -232,6 +233,8 @@ static void
 GSwitchItPreviewResponse (GtkWidget * dialog, gint resp)
 {
 	GdkRectangle rect;
+	GtkWidget *kbdraw;
+	const gchar *groupName;
 
 	switch (resp) {
 	case GTK_RESPONSE_HELP:
@@ -246,16 +249,28 @@ GSwitchItPreviewResponse (GtkWidget * dialog, gint resp)
 				     &rect.height);
 		gkbd_preview_save_position (&rect);
 		gtk_widget_destroy (dialog);
+		break;
+	case GTK_RESPONSE_PRINT:
+		kbdraw =
+		    GTK_WIDGET (g_object_get_data
+				(G_OBJECT (dialog), "kbdraw"));
+		groupName =
+		    (const gchar *) g_object_get_data (G_OBJECT (dialog),
+						       "groupName");
+		gkbd_keyboard_drawing_print (GKBD_KEYBOARD_DRAWING
+					     (kbdraw), GTK_WINDOW (dialog),
+					     groupName ? groupName :
+					     _("Unknown"));
 	}
 }
 
 static void
 GSwitchItPreviewDestroy (GtkWidget * dialog, gint group)
 {
-	GladeXML *gladeData =
-	    GLADE_XML (gtk_object_get_data
-		       (GTK_OBJECT (dialog), "gladeData"));
-	g_object_unref (G_OBJECT (gladeData));
+	GtkBuilder *builder =
+	    GTK_BUILDER (gtk_object_get_data
+			 (GTK_OBJECT (dialog), "builderData"));
+	g_object_unref (G_OBJECT (builder));
 	g_hash_table_remove (globals.previewDialogs,
 			     GINT_TO_POINTER (group));
 }
@@ -264,14 +279,20 @@ void
 GSwitchItAppletCmdPreview (BonoboUIComponent *
 			   uic, GSwitchItApplet * sia, const gchar * verb)
 {
-	static GkbdKeyboardDrawingGroupLevel groupsLevels[] =
-	    { {0, 1}, {0, 3}, {0, 0}, {0, 2} };
+	static GkbdKeyboardDrawingGroupLevel groupsLevels[] = { {
+								 0, 1}, {
+									 0,
+									 3},
+	{
+	 0, 0}, {
+		 0, 2}
+	};
 	static GkbdKeyboardDrawingGroupLevel *pGroupsLevels[] = {
 		groupsLevels, groupsLevels + 1, groupsLevels + 2,
 		groupsLevels + 3
 	};
 #ifdef HAVE_XKB
-	GladeXML *gladeData;
+	GtkBuilder *builder;
 	GtkWidget *dialog, *kbdraw;
 	XkbComponentNamesRec componentNames;
 	XklConfigRec *xklData;
@@ -289,19 +310,35 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 		return;
 	}
 #ifdef HAVE_XKB
-	gladeData =
-	    glade_xml_new (GNOME_GLADEDIR "/gswitchit.glade",
-			   "gswitchit_layout_view", NULL);
-	dialog = glade_xml_get_widget (gladeData, "gswitchit_layout_view");
+	GError *error = NULL;
+
+	builder = gtk_builder_new ();
+	gtk_builder_add_from_file (builder, GTK_BUILDERDIR "/gswitchit.ui",
+				   &error);
+
+	if (error) {
+		g_error ("building ui from %s failed: %s",
+			 GTK_BUILDERDIR "/gswitchit.ui", error->message);
+		g_clear_error (&error);
+	}
+
+
+	dialog =
+	    GTK_WIDGET (gtk_builder_get_object
+			(builder, "gswitchit_layout_view"));
 	kbdraw = gkbd_keyboard_drawing_new ();
 
 	if (xklState->group >= 0 &&
 	    xklState->group < g_strv_length (groupNames)) {
-		char title[128];
+		char title[128] = "";
 		snprintf (title, sizeof (title),
 			  _("Keyboard Layout \"%s\""),
 			  groupNames[xklState->group]);
 		gtk_window_set_title (GTK_WINDOW (dialog), title);
+		g_object_set_data_full (G_OBJECT (dialog), "groupName",
+					g_strdup (groupNames
+						  [xklState->group]),
+					g_free);
 	}
 
 	gkbd_keyboard_drawing_set_groups_levels (GKBD_KEYBOARD_DRAWING
@@ -351,7 +388,7 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 	}
 	g_object_unref (G_OBJECT (xklData));
 
-	gtk_object_set_data (GTK_OBJECT (dialog), "gladeData", gladeData);
+	gtk_object_set_data (GTK_OBJECT (dialog), "builderData", builder);
 	g_signal_connect (GTK_OBJECT (dialog),
 			  "destroy", G_CALLBACK (GSwitchItPreviewDestroy),
 			  GINT_TO_POINTER (xklState->group));
@@ -370,8 +407,10 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
 
 	gtk_container_add (GTK_CONTAINER
-			   (glade_xml_get_widget
-			    (gladeData, "preview_vbox")), kbdraw);
+			   (gtk_builder_get_object
+			    (builder, "preview_vbox")), kbdraw);
+
+	gtk_object_set_data (GTK_OBJECT (dialog), "kbdraw", kbdraw);
 
 	g_hash_table_insert (globals.previewDialogs,
 			     GINT_TO_POINTER (xklState->group), dialog);
@@ -397,7 +436,6 @@ GSwitchItAppletCmdPlugins (BonoboUIComponent *
 		g_error_free (error);
 	}
 }
-
 static void
 GSwitchItAppletCmdSetGroup (BonoboUIComponent
 			    * uic, GSwitchItApplet * sia,
@@ -436,25 +474,20 @@ GSwitchItAppletCmdHelp (BonoboUIComponent
 	gnome_help_display_on_screen ("gswitchit", NULL,
 				      gtk_widget_get_screen (sia->applet),
 				      NULL);
-}
-
-void
+} void
 GSwitchItAppletCmdAbout (BonoboUIComponent *
 			 uic, GSwitchItApplet * sia, const gchar * verb)
 {
 	const gchar *authors[] = {
-		"Sergey V. Udaltsov<svu@gnome.org>",
-		NULL
+		"Sergey V. Udaltsov<svu@gnome.org>", NULL
 	};
 	const gchar *documenters[] = {
-		"Sergey V. Udaltsov<svu@gnome.org>",
-		NULL
+		"Sergey V. Udaltsov<svu@gnome.org>", NULL
 	};
 
 	const gchar *translator_credits = _("translator-credits");
 
-	gtk_show_about_dialog (NULL,
-			       "version", VERSION,
+	gtk_show_about_dialog (NULL, "version", VERSION,
 /* Translators: Please replace (C) with the proper copyright character. */
 			       "copyright",
 			       _
@@ -467,7 +500,7 @@ GSwitchItAppletCmdAbout (BonoboUIComponent *
 			       strcmp (translator_credits,
 				       "translator-credits") !=
 			       0 ? translator_credits : NULL,
-			       "logo-icon-name", "gswitchit-applet", NULL);
+			       "logo-icon-name", "input-keyboard", NULL);
 }
 
 static void
@@ -550,9 +583,9 @@ GSwitchItAppletSetupMenu (GSwitchItApplet * sia)
 	/* Layout preview is for XKB only */
 	bonobo_ui_component_set_prop (popup, "/commands/Preview",
 				      "sensitive",
-				      g_strcasecmp ("XKB",
-						    engine_backend_name) ?
-				      "0" : "1", NULL);
+				      g_ascii_strcasecmp ("XKB",
+							  engine_backend_name)
+				      ? "0" : "1", NULL);
 
 	/* Delete the plugins item if the binary does not exist */
 	if (pluginsCappletFullPath == NULL)
@@ -578,7 +611,7 @@ GSwitchItAppletInit (GSwitchItApplet * sia, PanelApplet * applet)
 
 	g_set_application_name (_("Keyboard Indicator"));
 
-	gtk_window_set_default_icon_name ("gswitchit-applet");
+	gtk_window_set_default_icon_name ("input-keyboard");
 
 	sia->applet = GTK_WIDGET (applet);
 
